@@ -58,10 +58,14 @@ def pseudovar_component_props(varname: str):
     plot_extras = attrs['plot_options']['extras']
     dat = pytplot.get_data(varname)
 
-    if ylog is None or ylog == '' or ylog.lower() == 'linear':
+    if ylog is None or ylog is False or ylog == '' or ylog.lower() == 'linear':
         output_dict['ylog'] = False
+        ylog = False
     else:
         output_dict['ylog'] = True
+        ylog = True
+
+    # ylog is now guaranteed to be boolean
 
     if plot_extras.get('spec') is not None:
         spec = plot_extras['spec']
@@ -92,7 +96,7 @@ def pseudovar_component_props(varname: str):
                             if plot_extras['spec_dim_to_plot'] == 'v2':
                                 input_bin_centers = var_data.v2
 
-                output_bin_boundaries = specplot_make_1d_ybins(None, input_bin_centers, no_regrid=True)
+                output_bin_boundaries = specplot_make_1d_ybins(None, input_bin_centers, ylog, no_regrid=True)
                 output_dict['ymin']=np.nanmin(output_bin_boundaries)
                 output_dict['ymax']=np.nanmax(output_bin_boundaries)
 
@@ -164,7 +168,7 @@ def gather_pseudovar_props(pseudovars:list[str]):
 
     for var in pseudovars:
         props = pseudovar_component_props(var)
-        print(f"{var}: is_spec: {props['is_spec']} ymin: {props['ymin']} ymax: {props['ymax']} ylog: {props['ylog']} zmin: {props['zmin']} zmax: {props['zmax']} zlog: {props['zlog']}")
+        #print(f"{var}: is_spec: {props['is_spec']} ymin: {props['ymin']} ymax: {props['ymax']} ylog: {props['ylog']} zmin: {props['zmin']} zmax: {props['zmax']} zlog: {props['zlog']}")
         if props['is_spec']:
             output_dict['has_spec_plots'] = True
             if output_dict['first_spec_var'] is None:
@@ -219,8 +223,14 @@ def tplot(variables, var_label=None,
         logging.warning("tplot: No matching tplot names were found")
         return
 
-    num_panels = len(variables)
-    panel_sizes = [1]*num_panels
+
+    varlabel_style = pytplot.tplot_opt_glob.get('varlabel_style')
+    if varlabel_style is None or varlabel_style.lower() == 'extra_axes':
+        num_panels = len(variables)
+        panel_sizes = [1]*num_panels
+    else: # varlabel_style 'extra_panel'
+        num_panels = len(variables) + 1
+        panel_sizes = [1] * len(variables) + [0.1 * (len(var_label) + 2)]
 
     # support for the panel_size option
     for var_idx, variable in enumerate(variables):
@@ -241,7 +251,9 @@ def tplot(variables, var_label=None,
             if num_panels > 4:
                 ysize = 8
             else:
-                ysize = 5
+                # This was previously set to 5, which resulted in a non-monotonic progression of panel heights
+                default_y_sizes = [5, 5, 6, 7, 8]
+                ysize = default_y_sizes[num_panels]
 
     # The logic here for handling the 'right_axis' option is pretty convoluted, and makes a number of assumptions
     # that may not be warranted: mainly that right_axis will only be set on pseudovariables, and that if
@@ -380,16 +392,60 @@ def tplot(variables, var_label=None,
 
             traces_processed = 0
             pseudovar_props = gather_pseudovar_props(pseudo_vars)
+            #
+            # Determine which Y axis options need to be changed to accommodate multiple component variables
+            # There might be line variables and spectra, each with their own overall yscale and yrange.
+            # If both are present, the spectra will take priority.
+            # If explicit y or z scales or ranges are set on the pseudovariable, do not override.
+            if pseudovar_props['has_spec_plots']:
+                if pseudovar_props['spec_ylog']:
+                    new_yscale = 'log'
+                else:
+                    new_yscale = 'linear'
+                new_yr = [pseudovar_props['spec_ymin'], pseudovar_props['spec_ymax']]
+            else:
+                if pseudovar_props['line_ylog']:
+                    new_yscale = 'log'
+                else:
+                    new_yscale = 'linear'
+                new_yr = [pseudovar_props['line_ymin'], pseudovar_props['line_ymax']]
+            override_yopts = {}
+            if pseudo_right_axis:
+                # Who knows?  Let the component variable Y-axis fight it out...
+                override_yopts = {}
+            elif yaxis_options is None:
+                override_yopts = {'y_range':new_yr, 'y_range_user':True,'y_axis_style':new_yscale}
+            else:
+                if yaxis_options.get('y_range') is None:
+                    override_yopts['y_range'] = new_yr
+                    override_yopts['y_range_user'] = True
+                if yaxis_options.get('y_axis_style') is None:
+                    override_yopts['y_axis_style'] = new_yscale
+            if yaxis_options is not None:
+                yaxis_options = yaxis_options | override_yopts
+            else:
+                yaxis_options = override_yopts
+
+            # Determine which Z axis options need to be changed to accommodate multiple component variables
+            #
+            # We only care about specplots here.
             new_zr = [ None, pseudovar_props['spec_zmax']]
             if pseudovar_props['spec_zlog']:
                 new_zscale='log'
             else:
                 new_zscale='linear'
-            override_spec_zopts = {'z_range':new_zr, 'z_axis_style':new_zscale}
-            if zaxis_options is not None:
-                zaxis_options = zaxis_options | override_spec_zopts
+            override_zopts = {}
+            if zaxis_options is None:
+                override_zopts = {'z_range':new_zr, 'z_axis_style':new_zscale}
             else:
-                zaxis_options = override_spec_zopts
+                if zaxis_options.get('z_range') is None:
+                    override_zopts['z_range'] = new_zr
+                if zaxis_options.get('z_axis_style') is None:
+                    override_zopts['z_axis_style'] = new_zscale
+            if zaxis_options is not None:
+                zaxis_options = zaxis_options | override_zopts
+            else:
+                zaxis_options = override_zopts
 
             for pseudo_idx, var in enumerate(pseudo_vars):
                 # We're plotting a pseudovariable.  Iterate over the sub-variables, keeping track of how many
@@ -671,39 +727,12 @@ def tplot(variables, var_label=None,
                                    rotation=annotation['rotation'],
                                    color=annotation['color'])
 
-    # apply any addition x-axes specified by the var_label keyword
+    # apply any addition x-axes (or panel) specified by the var_label keyword
     if var_label is not None:
-        if not isinstance(var_label, list):
-            var_label = [var_label]
-
-        axis_delta = 0.0
-
-        for label in var_label:
-            if isinstance(label, int):
-                label = tname_byindex(label)
-            label_data = pytplot.get_data(label, xarray=True, dt=True)
-
-            if label_data is None:
-                logging.info('Variable not found: ' + label)
-                continue
-
-            if len(label_data.values.shape) != 1:
-                logging.info(label + ' specified as a vector; var_label only supports scalars. Try splitting the vector into seperate tplot variables.')
-                continue
-
-            # set up the new x-axis
-            axis_delta = axis_delta - num_panels*0.1
-            new_xaxis = this_axis.secondary_xaxis(axis_delta)
-            xaxis_ticks = this_axis.get_xticks().tolist()
-            xaxis_ticks_dt = [np.datetime64(mpl.dates.num2date(tick_val).replace(tzinfo=None).isoformat()) for tick_val in xaxis_ticks]
-            # xaxis_ticks_unix = [tick_val.timestamp() for tick_val in xaxis_ticks_dt]
-            xaxis_labels = get_var_label_ticks(label_data, xaxis_ticks_dt)
-            new_xaxis.set_xticks(xaxis_ticks_dt)
-            new_xaxis.set_xticklabels(xaxis_labels)
-            ytitle = pytplot.data_quants[label].attrs['plot_options']['yaxis_opt']['axis_label']
-            new_xaxis.set_xlabel(ytitle)
-
-        # fig.subplots_adjust(bottom=0.05+len(var_label)*0.1)
+        if varlabel_style is None or varlabel_style.lower() == 'extra_axes':
+            varlabels_extra_axes(num_panels, this_axis, var_label)
+        else:
+            pytplot.var_label_panel(variables, var_label, axes,  axis_font_size)
 
     # add the color bars to any spectra
     for idx, variable in enumerate(variables):
@@ -784,6 +813,7 @@ def tplot(variables, var_label=None,
                                    fontsize=char_size)
 
     # plt.tight_layout()
+    fig.canvas.draw()
 
     if save_png is not None and save_png != '':
         if not save_png.endswith('.png'):
@@ -822,6 +852,45 @@ def tplot(variables, var_label=None,
     if return_plot_objects:
         return fig, axes
 
+
+def varlabels_extra_axes(num_panels, this_axis, var_label):
+    # apply any addition x-axes specified by the var_label keyword
+    if var_label is not None:
+        if not isinstance(var_label, list):
+            var_label = [var_label]
+
+        axis_delta = 0.0
+
+        for label in var_label:
+            if isinstance(label, int):
+                label = tname_byindex(label)
+            label_data = pytplot.get_data(label, xarray=True, dt=True)
+
+            if label_data is None:
+                logging.info('Variable not found: ' + label)
+                continue
+
+            if len(label_data.values.shape) != 1:
+                logging.info(
+                    label + ' specified as a vector; var_label only supports scalars. Try splitting the vector into seperate tplot variables.')
+                continue
+
+            # set up the new x-axis
+            axis_delta = axis_delta - num_panels * 0.1
+            new_xaxis = this_axis.secondary_xaxis(axis_delta)
+            xaxis_ticks = this_axis.get_xticks().tolist()
+            xaxis_ticks_dt = [np.datetime64(mpl.dates.num2date(tick_val).replace(tzinfo=None).isoformat(), 'ns') for
+                              tick_val in xaxis_ticks]
+            # xaxis_ticks_unix = [tick_val.timestamp() for tick_val in xaxis_ticks_dt]
+            xaxis_labels = get_var_label_ticks(label_data, xaxis_ticks_dt)
+            new_xaxis.set_xticks(xaxis_ticks_dt)
+            new_xaxis.set_xticklabels(xaxis_labels)
+            ytitle = pytplot.data_quants[label].attrs['plot_options']['yaxis_opt']['axis_label']
+            new_xaxis.set_xlabel(ytitle)
+
+        # fig.subplots_adjust(bottom=0.05+len(var_label)*0.1)
+
+
 def mouse_move_slice(event, slice_axes, slice_plot):
     """
     This function is called when the mouse moves over an axis
