@@ -5,6 +5,7 @@
 
 from __future__ import division
 import os
+import logging
 import datetime
 import math
 import numpy as np
@@ -84,70 +85,24 @@ def option_usage():
 def set_tplot_options(option, value, old_tplot_opt_glob):
     new_tplot_opt_glob = old_tplot_opt_glob
     
-    if option == 'title':
+    if option in ['title_text', 'title']:
         new_tplot_opt_glob['title_text'] = value
     
     elif option == 'title_size':
-        str_size = str(value) + 'pt'
-        new_tplot_opt_glob['title_size'] = str_size
-        
-    elif option == 'wsize':
-        new_tplot_opt_glob['window_size'] = value
-        
-    elif option == 'title_align':
-        new_tplot_opt_glob['title_align'] = value
+        new_tplot_opt_glob['title_size'] = value
         
     elif option == 'var_label':
         new_tplot_opt_glob['var_label'] = value
-        
-    elif option == 'alt_range':
-        new_tplot_opt_glob['alt_range'] = value
-
-    elif option == 'map_x_range':
-        new_tplot_opt_glob['map_x_range'] = value
-
-    elif option == 'map_y_range':
-        new_tplot_opt_glob['map_y_range'] = value
 
     elif option == 'x_range':
         new_tplot_opt_glob['x_range'] = value
 
-    elif option == 'crosshair':
-        new_tplot_opt_glob['crosshair'] = value
-
     elif option == 'data_gap':
         new_tplot_opt_glob['data_gap'] = value
-    
-    elif option == 'roi':
-        new_tplot_opt_glob['roi_lines'] = value
-
-    elif option == 'vertical_spacing':
-        new_tplot_opt_glob['vertical_spacing'] = value
-
-    elif option == 'show_all_axes':
-        new_tplot_opt_glob['show_all_axes'] = value
-
-    elif option == 'min_border_top':
-        new_tplot_opt_glob['min_border_top'] = value
-
-    elif option == 'min_border_bottom':
-        new_tplot_opt_glob['min_border_bottom'] = value
-
-    elif option == 'black_background':
-        new_tplot_opt_glob['black_background'] = value
 
     elif option == 'axis_font_size':
         new_tplot_opt_glob['axis_font_size'] = value
 
-    elif option == 'axis_tick_num':
-        new_tplot_opt_glob['axis_tick_num'] = value
-
-    elif option == 'yaxis_width':
-        new_tplot_opt_glob['yaxis_width'] = value
-
-    elif option == 'y_axis_zoom':
-        new_tplot_opt_glob['y_axis_zoom'] = value
-
     elif option == 'xmargin':
         new_tplot_opt_glob['xmargin'] = value
 
@@ -166,8 +121,11 @@ def set_tplot_options(option, value, old_tplot_opt_glob):
     elif option == 'ysize':
         new_tplot_opt_glob['ysize'] = value
 
+    elif option == 'varlabel_style':
+        new_tplot_opt_glob['varlabel_style'] = value
+
     else:
-        print("Unknown option supplied: " + str(option))
+        logging.warning("Unknown option supplied: " + str(option))
 
     return new_tplot_opt_glob
 
@@ -311,7 +269,7 @@ def timebar_delete(t, varname=None, dim='height'):
             varname = [varname]
         for i in varname:
             if i not in pytplot.data_quants.keys():
-                print(str(i) + " is currently not in pytplot.")
+                logging.info(str(i) + " is currently not in pytplot.")
                 return
             if isinstance(pytplot.data_quants[i], dict):
                 # non-record varying variable
@@ -715,7 +673,11 @@ def reduce_spec_dataset(tplot_dataset=None, name=None):
     else:
         return
 
-    coordinate_to_plot = da.attrs['plot_options']['extras']['spec_dim_to_plot']
+    if da.attrs['plot_options']['extras'].get('spec_dim_to_plot', None) is not None:
+        coordinate_to_plot = da.attrs['plot_options']['extras']['spec_dim_to_plot']
+    else:
+        # If not found, default to v2 (to match behavior in options.py when setting "spec" option)
+        coordinate_to_plot = "v2"
 
     dim_to_plot = coordinate_to_plot + '_dim'
 
